.. _index:

#######
vcspull
#######

.. include:: ../README.rst
    :start-line: 4
    :end-before: .. image

.. image:: _static/vcspull-demo.gif
    :width: 100%

More information
----------------

.. include:: ../README.rst
    :start-after: More information
                 
.. toctree::
   :maxdepth: 2

   quickstart
   examples
   cli
   developing
   history
